class DogsController < ApplicationController
  # GET /dogs
  # GET /dogs.xml
  before_filter :authorize , :except => [:index,:show]
  helper :all

  def index
    #@dogs = Dog.find_all_by_user_id(params[:user_id])
    @dogs = Dog.paginate_by_user_id(params[:user_id],:page => params[:page],:per_page=>5,:order => 'name')
    @user_id = params[:user_id]

    respond_to do |format|
      format.html # index.html.erb
      format.xml  { render :xml => @dogs }
    end
  end

  # GET /dogs/1
  # GET /dogs/1.xml
  def show
    @dog = Dog.find(params[:id])    

    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @dog }
    end
  rescue ActiveRecord::RecordNotFound
    logger.error("Attempt to access invalid" )
    redirect_to_home("O animal não existe!")
  end

  # GET /dogs/new
  # GET /dogs/new.xml
  def new
    @dog = Dog.new
       
    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @dog }
    end
  end

  # GET /dogs/1/edit
  def edit
    @dog = Dog.find(params[:id])
  rescue ActiveRecord::RecordNotFound
    logger.error("Attempt to access invalid" )
    redirect_to_home("O animal não existe")
  end

  # POST /dogs
  # POST /dogs.xml
  def create
    @dog = Dog.new(params[:dog])
   
    @dog.user_id = params[:user_id]
   
    respond_to do |format|
      if @dog.save
        flash[:notice] = 'Dog was successfully created.'
        format.html { redirect_to(:controller=>'dogs',:action => 'show',:id => @dog,:user_id => @dog.user_id) }
        format.xml  { render :xml => @dog, :status => :created, :location => @dog }
      else
        format.html { render :action => "new" }
        format.xml  { render :xml => @dog.errors, :status => :unprocessable_entity }
      end
    end
  end

  # PUT /dogs/1
  # PUT /dogs/1.xml
  def update
    
    respond_to do |format|
      if @dog.update_attributes(params[:dog])
        flash[:notice] = 'Dog was successfully updated.'
        format.html { redirect_to(:controller=>'dogs',:action => 'show',:id => params[:dog_id],:user_id => params[:user_id]) }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @dog.errors, :status => :unprocessable_entity }
      end
    end
  end

  # DELETE /dogs/1
  # DELETE /dogs/1.xml
  def destroy
    @dog.destroy

    respond_to do |format|
      format.html { redirect_to(:controller => 'dogs',:action => 'index',:id=> params[:dog_id], :user_id => params[:user_id]) }
      format.xml  { head :ok }
    end

  rescue ActiveRecord::RecordNotFound
    logger.error("Attempt to access invalid" )
    redirect_to_home("O Animal Já está excluído")

  end

  protected
  
  def authorize
    if((params[:action]=='destroy') or (params[:action] == 'update'))
      @dog = Dog.find(params[:id])
      params[:user_id] = @dog.user_id
      params[:dog_id] = @dog.id
    end
    if(session[:user_log].nil?)
      flash[:notice] = "Acesso Restrito ao Usuario"
      redirect_to :controller => 'site' , :action => 'login'
    elsif(session[:user_log].to_i != params[:user_id].to_i)
      flash[:notice] = "Acesso Restrito ao Usuario #{params[:user_id]}"
      redirect_to :controller => 'users' , :action => 'show',:id=>params[:user_id]
    end
  end

  private

  def redirect_to_home(msg = nil)
    flash[:notice] = msg if msg
    redirect_to :controller =>'users',:action => 'home',:id => session[:user_log]
  end

end
