class Dog < ActiveRecord::Base
  has_attached_file :image, :styles => {:small => "150x150#", :default => "300x300#"}

  validates_presence_of :name,:breed,:size,:birth,:pedigree,:gender
  validates_attachment_presence :image

  validates_length_of :name , :maximum => 15
  validates_numericality_of :weight

  has_many :photos, :dependent => :destroy
  belongs_to :user

  BREED_OPTIONS = ["Beagle","Boxer", "Chihuahua ","Dálmata","Dogue Alemão","Fila Brasileiro","Husky Siberiano","Lhasa Apso","Cão Maltês","Mastim Napolitano","Pastor Alemão","Pequinês","Pinscher Miniatura","Pit bull","Poodle","Rottweiler","São Bernardo","Shih-Tzu","Yorkshire Terrier","Basset Hound","Border Collie
    ","Buldogue Inglês","Labrador","Chow-Chow","Dobermann", "Outra"]
  SIZE_OPTIONS = ["Grande","Médio","Pequeno"]
  GENDER_OPTIONS = ["Masculino","Feminino"]
  PEDIGREE_OPTIONS = ["Com Pedigree","Sem Pedigree"]

  def self.conditions_by_like_multi(values)
    conditions = ""
    for value in values
      if value == values.first
        conditions = conditions + self.conditions_by_like(value)
      else
        conditions ="(" + conditions + ") AND (" + self.conditions_by_like(value) + ")"
      end
    end
    conditions
  end

  def self.conditions_by_like(value, *columns)
    columns = self.columns if columns.size==0
    columns = columns[0] if columns[0].kind_of?(Array)
    conditions = columns.map {|c|
      c = c.name if c.kind_of? ActiveRecord::ConnectionAdapters::Column
      "`#{c}` LIKE " + ActiveRecord::Base.connection.quote("%#{value}%" )
    }.join(" OR " )
  end

  
end