class User < ActiveRecord::Base
  has_attached_file :image, :styles => {:default => "150x150#"}
  has_many :dogs, :dependent => :destroy

  validates_presence_of :email,:name,:cep,:city
  validates_uniqueness_of :email , :message => "Este email já está cadastrado."

  attr_accessor :password_confirmation
  validates_confirmation_of :password
  validate :password_non_blank

  def self.authenticate(email, password)
    user = self.find_by_email(email)
    if user
      expected_password = encrypted_password(password, user.salt)
      if user.hashed_password != expected_password
        user = nil
      end
    end
    user
  end
  # 'password' is a virtual attribute
  def password
    @password
  end

  def password=(pwd)
    @password = pwd
    return if pwd.blank?
    create_new_salt
    self.hashed_password = User.encrypted_password(self.password, self.salt)
  end

  def self.conditions_by_like_multi(values)
    conditions = ""
    for value in values
      if value == values.first
        conditions = conditions + self.conditions_by_like(value)
      else
        conditions ="(" + conditions + ") AND (" + self.conditions_by_like(value) + ")"
      end
    end
    conditions
  end

  def self.conditions_by_like(value, *columns)
    columns = self.columns if columns.size==0
    columns = columns[0] if columns[0].kind_of?(Array)
    conditions = columns.map {|c|
      c = c.name if c.kind_of? ActiveRecord::ConnectionAdapters::Column
      "`#{c}` LIKE " + ActiveRecord::Base.connection.quote("%#{value}%" )
    }.join(" OR " )
  end
  
  private
  
  def password_non_blank
    errors.add(:password, "Missing password" ) if hashed_password.blank?
  end

  def create_new_salt
    self.salt = self.object_id.to_s + rand.to_s
  end
  
  def self.encrypted_password(password, salt)
    string_to_hash = password + "wibble" + salt
    Digest::SHA1.hexdigest(string_to_hash)
  end
   
end
